//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 2000  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// Glyph class - defines the data we hold about a key glyph
//

/**
 * Defines the data we hold about a key glyph.
 */
public class Glyph {

	// for a key glyph we hold the char on the key, the keyboard
	// keycode that it comes from (for the keyboard map window),
	// its shift state (again for the keyboard map window),
	// details about the finger responsible for striking the key, and
	// some notion about what group of keys that glyph is in
	private Character	character;
	private KeyCode		keycode;
	private KeyShiftState	shiftstate;
	private Finger		finger;
	private GlyphGroup	group;


	/**
	 * Constructor, mostly used in building tables.
	 */
	public Glyph( char character, KeyCode keycode, KeyShiftState shiftstate,
			Finger finger, GlyphGroup group ) {

		// save the key details, ensuring that any nulls are in fact
		// saved as the correct null object for the item, since nulls
		// won't go into the lookup tables well later on
		this.character	= new Character( character );
		this.keycode	= ( keycode != null ) ?
						keycode : KeyCode.KC_NULL;
		this.shiftstate	= ( shiftstate != null ) ?
						shiftstate
						: KeyShiftState.UNSHIFTED;
		this.finger	= ( finger != null ) ?
						finger : Finger.NO_FINGER;
		this.group	= ( group != null ) ?
						group : GlyphGroup.NO_GROUP;
	}


	/*
	 * Accessor methods.
	 */
	public Character	get_character()	{ return ( character ); }
	public KeyCode		get_keycode()	{ return ( keycode ); }
	public KeyShiftState	get_shiftstate(){ return ( shiftstate ); }
	public Finger		get_finger()	{ return ( finger ); }
	public GlyphGroup	get_group()	{ return ( group ); }


	/**
	 * Printout method.
	 */
	public String toString() {
		return ( getClass().getName() + "{character='" + character
				+ "',keycode=" + keycode
				+ ",shiftstate=" + shiftstate
				+ ",finger=" + finger
				+ ",group=" + group + "}" );
	}


	/**
	 * Class test code.
	 */
	public static void main ( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );

		System.out.println( new Glyph( 'a', KeyCode.KC_37,
				KeyShiftState.UNSHIFTED, Finger.LH_PINKY,
				GlyphGroup.UNSHIFTED_ALPHA ));
		System.out.println( new Glyph( 'Y', KeyCode.KC_28,
				KeyShiftState.SHIFTED, Finger.RH_INDEX,
				GlyphGroup.SHIFTED_ALPHA ));
		System.out.println( new Glyph( ' ', KeyCode.KC_64,
				KeyShiftState.UNSHIFTED, Finger.RH_THUMB,
				GlyphGroup.BASIC ));
		System.out.println( new Glyph( '*', null, null, null, null ));
	}
}
